Shopyoapi
=========

Shopyo has some api which eases your life

api.cmd
-------------

.. automodule:: api.cmd
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

api.database
------------------

.. automodule:: api.database
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

api.enhance
-----------------

.. automodule:: api.enhance
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

api.file
--------------

.. automodule:: api.file
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:



api.forms
---------------

.. automodule:: api.forms
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

api.html
--------------

.. automodule:: api.html
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

api.info
--------------

.. automodule:: api.info
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:


api.module
-----------------

.. automodule:: api.module
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: